@@ -7,7 +7,9 @@ use LWP;
 use JSON;
 use String::Random;
 
-our $VERSION = "1.04";
+use Data::Dumper;
+
+our $VERSION = "1.05";
 
 has 'server' => (
     is       => 'rw',
@@ -74,17 +76,26 @@ sub BUILD {
 sub do {
     my $self      = shift;
     my $method    = shift;
-    my %args      = @_;
+    my @args      = @_;
     my $id        = new String::Random;
     my $ua        = $self->ua;
     my $auth      = $self->auth;
     my $url       = $self->server;
+    my $params;
+    if (scalar @args == 1) {
+        $params = $args[0];
+    }
+    else {
+        my %params = @args;
+        $params = \%params;
+    }
+
     my $json_data = {
         jsonrpc => '2.0',
         id      => $id->randpattern("nnnnnnnnnn"),
         method  => $method,
         auth    => $auth,
-        params  => \%args,
+        params  => $params,
     };
     my $json = encode_json($json_data) or die($!);
     $self->{post_response} = $ua->post( $url, @content_type, Content => $json );
@@ -147,12 +158,16 @@ Zabbix::Tiny - A small module to eliminate boilerplate overhead when using the Z
       user     => $username
   );
 
-  my $hosts = $zabbix->do(
-      'host.get',  # First argument is the Zabbix API method
+  my $params = {
       output    => [qw(hostid name host)],  # Remaining paramters to 'do' are the params for the zabbix method.
       monitored => 1,
       limit     => 2,
       ## Any other params desired
+  };
+
+  my $hosts = $zabbix->do(
+      'host.get',  # First argument is the Zabbix API method
+      $params
   );
 
   # Print some of the retreived information.
@@ -188,9 +203,13 @@ This module was developed against Zabbix 2.4, and is expected to work with Zabbi
 
 The constructor requires server, user, and password.  It will create the Zabbix::Tiny object, and log in to the server all at once.  The C<ssl_opts> argument can be set to set the LWP::UserAgent ssl_opts attribute when connecting to https with a self-signed or otherwise un-trusted certificate (see note about untrusted certificates below).
 
-=item my $hosts = $zabbix->do('zabbix.method', %params);
+=item my $hosts = $zabbix->do('zabbix.method', ... );
 
-This will execute any defined Zabbix method, with the corresponding params.  Refer to the Zabbix manual for a list of available methods.  If the Zabbix method is of a *.get flavor, the return is an arrayref data structure containing the response from the Zabbix server.
+ my $hosts = $zabbix->do('zabbix.method', {%params});
+ my $hosts = $zabbix->do('zabbix.method', [@params]);
+ my $hosts = $zabbix->do('zabbix.method', %params); ## Depricated
+
+This will execute any defined Zabbix method, with the corresponding params.  Refer to the Zabbix manual for a list of available methods.  If the Zabbix method is of a *.get flavor, the return is an arrayref data structure containing the response from the Zabbix server.  Starting with v1.05, it is preferred to pass parameters as a hashref or an arrayref, since a few Zabbix API methods take an array, rather than a hash of parameters.  Support for params as a hash are still supported for backwards compatibility.
 
 =back
 
